==> bigloo1.3b.tar.gz: bigloo1.3/comptime1.3/Tools/module.scm <==
;*---------------------------------------------------------------------*/
;*    Copyright (c) 1993 by Manuel Serrano. All rights reserved.       */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \    /  '                              */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome Send them to                                           */
;*        <Manuel.Serrano@inria.fr>                                    */
;*        Manuel Serrano                                               */
;*        INRIA -- Rocquencourt                                        */
;*        Domaine de Voluceau, BP 105                                  */
;*        78153 Le Chesnay Cedex                                       */
;*        France                                                       */
;*---------------------------------------------------------------------*/


;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime1.2/Tools/module.scm ...     */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Apr  9 15:31:03 1993                          */
;*    Last change :  Fri Apr  9 16:09:56 1993  (serrano)               */
;*                                                                     */
;*    Les utilitaires sur les noms des module                          */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module tools_module
   (export (module-init-name module-name)))

;*---------------------------------------------------------------------*/
;*    module-init-name ...                                             */
;*---------------------------------------------------------------------*/
(define (module-init-name module-name)
   (string->symbol (string-append (symbol->string module-name)
				  "-initialisation")))

==> bigloo_1.8b.orig.tar.gz: bigloo-1.8b.orig/comptime1.8/Tools/module.scm <==
;*---------------------------------------------------------------------*/
;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \    /  '                              */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome Send them to                                           */
;*        <Manuel.Serrano@inria.fr>                                    */
;*        Manuel Serrano                                               */
;*        INRIA -- Rocquencourt                                        */
;*        Domaine de Voluceau, BP 105                                  */
;*        78153 Le Chesnay Cedex                                       */
;*        France                                                       */
;*---------------------------------------------------------------------*/


;*=====================================================================*/
;*    serrano/prgm/project/bigloo/comptime1.8/Tools/module.scm         */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Fri Apr  9 15:31:03 1993                          */
;*    Last change :  Thu May 18 17:11:46 1995 (serrano)                */
;*                                                                     */
;*    Les utilitaires sur les noms des module                          */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module tools_module
   (import engine_param)
   (export (module-init-name module-name)
	   (mark-import-module!  module)
	   (mark-library-module! module)
	   (mark-use-module!     module)))

;*---------------------------------------------------------------------*/
;*    module-init-name ...                                             */
;*---------------------------------------------------------------------*/
(define (module-init-name module-name)
   'initialization)

;*---------------------------------------------------------------------*/
;*    mark-import-module! ...                                          */
;*---------------------------------------------------------------------*/
(define (mark-import-module! module)
   (if (eq? (getprop module 'used) 'to-initialize)
       'done
       (begin
	  (set! *used-modules* (cons module *used-modules*))
	  (putprop! module 'used 'to-initialize))))

;*---------------------------------------------------------------------*/
;*    mark-library-module! ...                                         */
;*---------------------------------------------------------------------*/
(define (mark-library-module! module)
   (if (eq? (getprop module 'used) 'to-initialize)
       'done
       (begin
	  (set! *used-library-modules* (cons module *used-library-modules*))
	  (putprop! module 'used 'to-initialize))))

;*---------------------------------------------------------------------*/
;*    mark-use-module! ...                                             */
;*---------------------------------------------------------------------*/
(define (mark-use-module! module)
   (putprop! module 'used 'to-initialize))
